#

##

##

##

##

    	squashes
    		# aggregates
    		# balance sheets
    		# squeezes

    	summary

    		Every 100 blocks or so, a squash is generated
    		that aggregates everything before the squash.

    			Therefore, new businesses can start voting
    			without having to retrieve the entire
    			history of the universe.

    	physics

    		gestures per scene = 100

    	objectives ranked

    	possibilities

    		[ ] squeezes happen every few scenes